@@ -1,5 +1,6 @@
 package Dist::Zilla::Plugin::Author::Plicease::Init2;
 
+use 5.008001;
 use Moose;
 use Dist::Zilla::File::InMemory;
 use Dist::Zilla::File::FromCode;
@@ -8,15 +9,13 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.72'; # VERSION
+our $VERSION = '1.73'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
 with 'Dist::Zilla::Role::ModuleMaker';
 with 'Dist::Zilla::Role::FileGatherer';
 
-use namespace::autoclean;
-
 our $chrome;
 
 sub chrome
@@ -313,7 +312,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.72
+version 1.73
 
 =head1 DESCRIPTION
 
