@@ -1,11 +1,10 @@
 package Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup;
 
-use strict;
-use warnings;
+use 5.008001;
 use Moose;
 
 # ABSTRACT: add a travis status button to the README.md file
-our $VERSION = '1.72'; # VERSION
+our $VERSION = '1.73'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterBuild';
@@ -49,12 +48,22 @@ Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup - add a travis status but
 
 =head1 VERSION
 
-version 1.72
+version 1.73
 
 =head1 SYNOPSIS
 
  [Author::Plicease::TravisStatus]
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Dist::Zilla>
+
+=item L<Dist::Zilla::PluginBundle::Author::Plicease>
+
+=back
+
 =head1 AUTHOR
 
 Graham Ollis <perl@cpan.org>
