@@ -1,11 +1,10 @@
 package Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs;
 
-use strict;
-use warnings;
+use 5.008001;
 use Moose;
 
 # ABSTRACT: Special prereq handling
-our $VERSION = '1.72'; # VERSION
+our $VERSION = '1.73'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -121,7 +120,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 1.72
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -197,6 +196,16 @@ Recommended if Mojolicious or AnyEvent modules are required.
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Dist::Zilla>
+
+=item L<Dist::Zilla::PluginBundle::Author::Plicease>
+
+=back
+
 =head1 AUTHOR
 
 Graham Ollis <perl@cpan.org>
