@@ -1,13 +1,15 @@
 package Dist::Zilla::Plugin::Author::Plicease::Thanks;
 
+use 5.008001;
 use Moose;
+
 with 'Dist::Zilla::Role::FileMunger';
 with 'Dist::Zilla::Role::FileFinderUser' => {
   default_finders => [ ':InstallModules', ':ExecFiles' ],
 };
 
 # ABSTRACT: munge the AUTHOR section
-our $VERSION = '1.72'; # VERSION
+our $VERSION = '1.73'; # VERSION
 
 
 has original => (
@@ -100,7 +102,7 @@ Dist::Zilla::Plugin::Author::Plicease::Thanks - munge the AUTHOR section
 
 =head1 VERSION
 
-version 1.72
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -110,6 +112,16 @@ version 1.72
  contributor = Contributor One
  contributor = Contributor Two
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Dist::Zilla>
+
+=item L<Dist::Zilla::PluginBundle::Author::Plicease>
+
+=back
+
 =head1 AUTHOR
 
 Graham Ollis <perl@cpan.org>
