@@ -1,9 +1,10 @@
 package Dist::Zilla::Plugin::Author::Plicease::Upload;
 
+use 5.008001;
 use Moose;
 
 # ABSTRACT: Upload a dist to CPAN
-our $VERSION = '1.72'; # VERSION
+our $VERSION = '1.73'; # VERSION
 
 
 extends 'Dist::Zilla::Plugin::UploadToCPAN';
@@ -85,7 +86,7 @@ Dist::Zilla::Plugin::Author::Plicease::Upload - Upload a dist to CPAN
 
 =head1 VERSION
 
-version 1.72
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -127,6 +128,16 @@ Valid C<scp> destination if CPAN upload is disabled.
 
 Base web URL if CPAN upload is disabled.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Dist::Zilla>
+
+=item L<Dist::Zilla::PluginBundle::Author::Plicease>
+
+=back
+
 =head1 AUTHOR
 
 Graham Ollis <perl@cpan.org>
