@@ -1,5 +1,6 @@
 package Dist::Zilla::PluginBundle::Author::Plicease;
 
+use 5.008001;
 use Moose;
 use Dist::Zilla;
 use PerlX::Maybe qw( maybe );
@@ -9,13 +10,11 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.72'; # VERSION
+our $VERSION = '1.73'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-use namespace::autoclean;
-
 sub mvp_multivalue_args { qw( alien_build_command alien_install_command diag allow_dirty ) }
 
 sub configure
@@ -242,7 +241,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.72
+version 1.73
 
 =head1 SYNOPSIS
 
@@ -441,6 +440,24 @@ to install L<Dist::Zilla> and L<Dist::Zilla::PluginBundle::Author::Plicease>.
 
 Additional dirty allowed file passed to @Git.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Dist::Zilla>
+
+=item L<Dist::Zilla::Plugin::Author::Plicease::MarkDownCleanup>
+
+=item L<Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs>
+
+=item L<Dist::Zilla::Plugin::Author::Plicease::Tests>
+
+=item L<Dist::Zilla::Plugin::Author::Plicease::Thanks>
+
+=item L<Dist::Zilla::Plugin::Author::Plicease::Upload>
+
+=back
+
 =head1 AUTHOR
 
 Graham Ollis <perl@cpan.org>
